import $api from '../http/index'

export interface ITask {
  id: number,
  title: string | null,
  task: string,
  members: number,
  limit: number,
  deadline: string
}

export type IReports = Record<number, Record<number, IReport>>

export interface IReport {
  userId: number,
  reportId: number,
  enrolDate: string,
  surrenderDate: string | null,
  answerLink: string,
  credited: 0
}

export type ITaskSelf = ITask & Partial<IReport>

export default class HyperskillService {
  static async getTasks(): Promise<ITask[]> {
    try {
      const response = await $api.get<ITask[]>(`/reports`)
      // console.log('[getTasks] ', response)
      return response.data
    } catch (e) {
      return null as any
    }
  }

  // static async getProgress() {
  //   try {
  //     const response = await $api.get(`/reports/progress`)
  //     console.log('[getProgress] ', response)
  //     return response.data
  //   } catch (e) {
  //     return null as any
  //   }
  // }

  static async getTasksSelf(): Promise<ITaskSelf[]> {
    try {
      const response = await $api.get<ITaskSelf[]>(`/reports/self`)
      // console.log('[getTasksSelf] ', response)
      return response.data
    } catch (e) {
      return null as any
    }
  }

  static async upload(reportId: number, link: string): Promise<unknown> {
    try {
      const response = await $api.post<unknown>(`/reports`, {reportId, link})
      // console.log('[uploadReports] ', response)
      return response.data
    } catch (e) {
      return null as any
    }
  }

  static async getReportsProgress(): Promise<IReports> {
    try {
      const response = await $api.get<IReports>(`/reports/progress`)
      // console.log('[getReportsAdmin] ', response)
      return response.data
    } catch (e) {
      return null as any
    }
  }

  // static async changeReportsProgress(userId: number, reportId: number, value: boolean): Promise<unknown> {
  //   try {
  //     const response = await $api.post<unknown>(`/reports/progress`, {userId, reportId, value})
  //     // console.log('[changeReportsAdmin] ', response)
  //     return response.data
  //   } catch (e) {
  //     return null as any
  //   }
  // }

  static async changeReport(reportId: number | null, title: string | null, task: string, deadline: string, limit: number): Promise<{ id: number | null }> {
    try {
      const response = await $api.post<{ id: number | null }>(`/reports/admin`, {reportId, title, task, deadline, limit})
      // console.log('[changeReport] ', response)
      return response.data
    } catch (e) {
      return null as any
    }
  }

  static async enrolment(reportId: number, value: boolean): Promise<true> {
    try {
      const response = await $api.post<true>(`/reports/enrolment`, {reportId, value})
      // console.log('[enrolment] ', response)
      return response.data
    } catch (e) {
      return null as any
    }
  }

  static async deleteProject(projectId: number): Promise<{ status: 'OK' }> {
    try {
      const response = await $api.post<{ status: 'OK' }>(`/reports/delete`, {projectId})
      // console.log('[deleteProject] ', response)
      return response.data
    } catch (e) {
      return null as any
    }
  }

  // static async getReport(userId, reportId) {
  //     try {
  //         const response = await $api.get(`/reports/admin`, {params: {userId, reportId}})
  //         console.log('[getReportsAdmin] ', response)
  //         return response.data
  //     } catch (e) {
  //         return null as any
  //     }
  // }
}
