import $api from '../http/index'

export interface ISelfProgress {
  [key: number]: {
    created: number,
    description: string
  }
}

export interface IAllProgress {
  [key: number]: boolean[]
}

export default class ProgressService {
  static async getWorks(): Promise<string[]> {
    try {
      const response = await $api.get<string[]>('/progress/works')
      // console.log('[getWorks] ', response);
      return response.data
    } catch (e) {
      const message = e.response?.data?.message
      // console.log('[err] in getWorks, message: ', message)
      return message
    }
  }

  static async getSelf(): Promise<ISelfProgress> {
    try {
      const response = await $api.get<ISelfProgress>('/progress/self')
      // console.log('[getSelfProgress] ', response)
      return response.data
    } catch (e) {
      const message = e.response?.data?.message
      // console.log('[err] in getSelfProgress, message: ', message)
      return message
    }
  }

  static async get(): Promise<IAllProgress> {
    try {
      const response = await $api.get<IAllProgress>('/progress')
      // console.log('[getProgress] ', response.data)
      return response.data
    } catch (e) {
      const message = e.response?.data?.message
      // console.log('[err] in getProgress, message: ', message)
      return message
    }
  }

  static async set(userId: number, workId: number, val: boolean): Promise<{ status: 'OK' }> {
    try {
      const response = await $api.post<{ status: 'OK' }>('progress', {userId, workId, val})
      return response.data
    } catch (e) {
      const message = e.response?.data?.message
      // console.log('[err] in setProgress, message: ', message)
      return message
    }
  }

  static async getDescription(userId: number, workId: number): Promise<string | null> {
    try {
      const response = await $api.get<string | null>('progress/description', {params: {userId, workId}})
      console.log(response.data)

      return response.data
    } catch (e) {
      const message = e.response?.data?.message
      // console.log('[err] in setProgress, message: ', message)
      return message
    }
  }

  static async setDescription(userId: number, workId: number, val: string): Promise<{ status: 'OK' }> {
    try {
      const response = await $api.post<{ status: 'OK' }>('progress/description', {userId, workId, val})

      return response.data
    } catch (e) {
      const message = e.response?.data?.message
      // console.log('[err] in setProgress, message: ', message)
      return message
    }
  }
}
