import $api from '../http/index'
import {IUser} from '@/services/authService'

export interface IStudent extends Omit<IUser, 'isActivated' | 'isPassQuestionnaire' | 'tel'> {
  date: string
}

export type IStatusCodes = 0 | 1 | 2 | 100 | 101 | 102 | 200 | 201 | 300 | 301 | 342
export type IStatuses = { [key in IStatusCodes]: string }

export interface IStatusChanges {
  [key: number]: {
    email: string,
    status: number
  }
}

export default class UserService {
  static async fetchStudents(): Promise<IStudent[]> {
    try {
      const response = await $api.get<IStudent[]>('/students')
      // console.log('Студенты: ', response.data)
      return response.data
    } catch (e) {
      const message = e.response?.data?.message
      // console.log('[err] in fetchUsers, message: ', message)
      return message
    }
  }

  static async getStatuses(): Promise<IStatuses> {
    try {
      const response = await $api.get<IStatuses>('/statuses')
      // console.log('[Статусы] ', response.data)
      return response.data
    } catch (e) {
      const message = e.response?.data?.message
      // console.log('[err] in getStatuses, message: ', message)
      return message
    }
  }

  static async changeStatuses(statusChanges: IStatusChanges): Promise<IStudent[]> {
    try {
      const response = await $api.post<IStudent[]>('/statuses', statusChanges)
      // console.log('[Роли изменены] ', response.data)
      return response.data
    } catch (e) {
      const message = e.response?.data?.message
      // console.log('[err] in changeRole, message: ', message)
      return message
    }
  }

  static async changeTelegram(telegram: string): Promise<{ status: 'OK' }> {
    try {
      const response = await $api.post<{ status: 'OK' }>('/telegram', {telegram})
      // console.log('[Телеграм изменён] ', response.data)
      return response.data
    } catch (e) {
      const message = e.response?.data?.message
      // console.log('[err] in changeRole, message: ', message)
      return message
    }
  }
}
