import {onBeforeUnmount, onMounted, Ref, ref} from 'vue'

export const useActiveElement = function (type: Ref<string>, buttons: { [key: string]: Ref<HTMLButtonElement | undefined> }, useHook = true) {
  const stpMorph = ref('')

  const updateStpMorph = useHook ? (newType: string, noAnimation = false) => {
    type.value = newType
    const stpWidth = buttons[newType].value!.offsetWidth
    const parentsPadding = window.getComputedStyle(buttons[newType].value!.parentNode as HTMLElement).getPropertyValue('padding-left')
    const stpMargin = `calc(${buttons[newType].value!.offsetLeft}px - ${parentsPadding})`
    stpMorph.value = `width: ${stpWidth}px; transform: translate3d(${stpMargin}, 0, 0)`
    if (noAnimation) stpMorph.value += ';transition: none'
  } : () => {}

  if (useHook) {
    const silentUpdateStpMorph = () => updateStpMorph(type.value, true)
    onMounted(() => {
      silentUpdateStpMorph()
      window.addEventListener('resize', silentUpdateStpMorph)
    })
    onBeforeUnmount(() => window.removeEventListener('resize', silentUpdateStpMorph))
  }

  return {
    stpMorph,
    updateStpMorph,
  }
}
