import AvatarService from '@/services/avatarService'
import {Ref, ref} from 'vue'
import {IUser} from '@/services/authService'

export function useAvatar(user: Ref<IUser>) {
  const avatar = ref(require('@/assets/avatar.svg'))

  async function getCustomAvatar() {
    if (user.value.avatar) {
      const data = await AvatarService.getAvatar(`${user.value.id}_${user.value.avatar}.png`)
      if (data) avatar.value = data
      else user.value.avatar = undefined
    }
  }

  getCustomAvatar()


  const newAvatar = ref<string>()
  const avatarInput = ref<HTMLInputElement>()
  const showChangePopup = ref(false)

  const changeAvatar = (evt: InputEvent) => {
    const target = evt.target as HTMLInputElement
    const img = target.files![0]
    if (img && img.size < 5000001 && (img.type === 'image/png' || img.type === 'image/jpeg')) {
      const fr = new FileReader()
      fr.onload = (frEvt) => newAvatar.value = frEvt.target!.result as string
      fr.readAsDataURL(img)
    }
  }

  const setAvatar = async () => {
    const img = avatarInput.value!.files![0]
    if (img) {
      const file = new FormData()
      file.append('file', img)
      const {name} = await AvatarService.setAvatar(file)
      user.value.avatar = name
      showChangePopup.value = false
      avatar.value = newAvatar.value
    }
  }

  return {
    avatar,
    newAvatar,
    avatarInput,
    showChangePopup,
    changeAvatar,
    setAvatar,
  }
}
