import {ref} from 'vue'


export function useDragAndScroll(verticalScroll = false) {
  const el = ref()

  let pos = {top: 0, left: 0, x: 0, y: 0}

  const mouseDownHandler = function (e: MouseEvent) {
    const target = e.target as HTMLElement
    if (e.ctrlKey) {
      e.preventDefault()
      el.value.style.cursor = 'grabbing'
      el.value.style.userSelect = 'none'
      if (e.target !== el.value) target.style.pointerEvents = 'none'

      pos = {
        left: el.value.scrollLeft,
        top: el.value.scrollTop,
        x: e.clientX,
        y: e.clientY,
      }
      window.addEventListener('mousemove', mouseMoveHandler)
      window.addEventListener('mouseup', mouseUpHandler(target), {once: true})
    }
  }

  const mouseMoveHandler = function (e: MouseEvent) {
    const dx = e.clientX - pos.x
    el.value.scrollLeft = pos.left - dx

    if (verticalScroll) {
      const dy = e.clientY - pos.y
      el.value.scrollTop = pos.top - dy
    }
  }

  const mouseUpHandler = (target: HTMLElement) => function () {
    window.removeEventListener('mousemove', mouseMoveHandler)
    el.value.style.removeProperty('cursor')
    el.value.style.removeProperty('user-select')
    target.style.removeProperty('pointer-events')
  }

  return {
    dragAndScrollElement: el,
    mouseDownHandler,
    mouseMoveHandler,
    mouseUpHandler,
  }
}
