import {computed, reactive, Ref, ref, watch} from 'vue'
import {showMessage, useValidation} from '@/use/validation'
import {IStore} from '@/use/store'

export interface IAuthFormFields {
  email: string,
  password: string,
  secondPassword: string,
  name: string,
  surname: string,
  tel: string,
  telegram: string,
}

export const useForm = function (store: IStore, signType: Ref<'up' | 'in'>) {
  const fields = reactive<IAuthFormFields>({
    email: '',
    password: '',
    secondPassword: '',
    name: '',
    surname: '',
    tel: '',
    telegram: '',
  })

  const fldRefs = {email: ref<HTMLInputElement>(), pass1: ref<HTMLInputElement>()}

  const policy = ref(false)

  const submit = async function () {
    switch (signType.value) {
      case 'up': {
        const {email, password, name, surname, tel, telegram} = fields
        const res = await store.registration({email, password, name, surname, tel, telegram: telegram.replace('@', ''), policy: policy.value})
        if (res) showMessage(fldRefs.email.value!, res)
        break
      }
      case 'in': {
        const {email, password} = fields
        const res = await store.login({email, password})
        if (res) showMessage((res.includes('email') ? fldRefs.email.value! : fldRefs.pass1.value!), res)
        break
      }
    }
  }

  const isButtonDisabled = computed(() => (
    (signType.value === 'up' && (!policy.value || !fields.email || !fields.password || !fields.secondPassword || !fields.name || !fields.surname || !fields.tel)) ||
    (signType.value === 'in' && (!fields.email || !fields.password))
  ))

  watch(signType, () => {for (const fld of Object.values(fldRefs)) fld.value!.setCustomValidity('')})

  return {
    fields,
    ...fldRefs,
    ...useValidation(fields),
    policy,
    submit,
    isButtonDisabled,
  }
}
