import {reactive, ref} from 'vue'
import HyperskillService, {IReports, ITask, ITaskSelf} from '@/services/hyperskillService'

export type IEnrolment = (projectId: number, value: boolean) => Promise<void>

export function useHyperskill() {
  const tasks = ref<ITaskSelf[]>([])
  const activeReportIdx = ref<number>()

  HyperskillService.getTasksSelf().then((val) => {tasks.value = val})

  const link = ref<string>()

  const showTask = (id: number) => {
    const idx = tasks.value.findIndex((task) => task.id === id)
    if (idx !== -1 && activeReportIdx.value !== idx) {
      activeReportIdx.value = idx
      link.value = tasks.value[idx].answerLink!
    } else activeReportIdx.value = link.value = undefined
  }

  const upload = async function () {
    if (!!tasks.value[activeReportIdx.value!].task) {
      const activeIdx = activeReportIdx.value!
      const activeLink = link.value
      if (await HyperskillService.upload(tasks.value[activeReportIdx.value!].id, link.value!)) {
        tasks.value[activeIdx].answerLink = activeLink
        tasks.value[activeIdx].surrenderDate = String(Date.now())
        activeReportIdx.value = link.value = undefined
      }
    }
  }

  const enrolment = async function (projectId: number, value: boolean) {
    const project = tasks.value.find(({id}) => id === projectId)
    if (!!project && project.members < project.limit) {
      if (await HyperskillService.enrolment(projectId, value)) {
        project.enrolDate = value ? String(Date.now()) : undefined
        project.members += value ? 1 : -1
      }
    }
  }

  return {
    tasks,
    activeReportIdx,
    showTask,
    link,
    upload,
    enrolment,
  }
}

export type IAdminHsStore = ReturnType<typeof useAdminHyperskill>['hsStore']

export function useAdminHyperskill() {
  const tasks = ref<ITask[]>([])

  HyperskillService.getTasks().then((val) => {if (val) tasks.value = val})

  const progress = ref<IReports>({})

  HyperskillService.getReportsProgress().then((val) => {if (val) progress.value = val})

  // const changeProgress = async (userId, reportId) => {
  //     const field = progress.value[userId]?.[reportId]
  //     if (field) await HyperskillService.changeReportsProgress(userId, reportId, field.credited)
  // }

  const changeTask = async (task: string, deadline: string, limit: number, originalObj: ITask | null = null, title: string | null = null) => {
    if (originalObj) {
      const isProjectChanged = originalObj.task !== task || originalObj.deadline !== deadline || originalObj.limit !== limit
      if (isProjectChanged) await HyperskillService.changeReport(originalObj.id, title, task, deadline, limit)
    } else {
      const id = (await HyperskillService.changeReport(null, title, task, deadline, limit)).id!
      tasks.value.push({id, title, task, deadline, limit, members: 0})
    }
  }

  const deleteTask = async (projectId: number) => {
    if (await HyperskillService.deleteProject(projectId)) {
      tasks.value = tasks.value.filter(({id}) => id !== projectId)
    }
  }

  return {
    hsStore: reactive(
      {
        tasks,
        progress,
        changeTask,
        deleteTask,
        // changeProgress,
      },
    ),
  }
}
