import {reactive, Ref, watch} from 'vue'
import UserService, {IStatusChanges, IStudent} from '@/services/userService'

export function useStatusBuffer(students: Ref<IStudent[]>, onStatusChanges: Function) {
  const statusBuffer = reactive<IStatusChanges>({})

  watch(() => { return {...statusBuffer}}, (newValue, oldValue) => {
    if (Object.keys(oldValue).length <= Object.keys(newValue).length) {
      let key: keyof IStatusChanges, val: valueOf<IStatusChanges>
      for (const [k, v] of Object.entries(newValue)) {
        const nK = Number(k)
        if (!oldValue[nK] || oldValue[nK] && oldValue[nK].status !== v.status) {
          [key, val] = [nK, v]
          break
        }
      }
      if (students.value.find(({id, status}) => id === key && status === val.status)) delete statusBuffer[key!]
    }
  })

  const saveStatusChanges = async () => {
    students.value = await UserService.changeStatuses(statusBuffer)
    onStatusChanges()
    for (const key of Object.keys(statusBuffer)) delete statusBuffer[Number(key)]
  }

  return {
    statusBuffer,
    saveStatusChanges,
  }
}
