import {reactive, ref, watch} from 'vue'
import UserService, {IStudent} from '@/services/userService.ts'
import {useStatusBuffer} from '@/use/statusBuffer'

export type ISortField = { field: keyof IStudent | null }

export function useStudents() {
  const students_prg = ref<IStudent[]>([])
  const students_adm = ref<IStudent[]>([])

  UserService.fetchStudents().then(val => {
    students_prg.value = val
    students_adm.value = JSON.parse(JSON.stringify(val))
  })

  const sortField = reactive<ISortField>({field: null})
  const sort = (field: keyof IStudent) => {
    students_adm.value.sort((a, b) => {
      if (a[field]! < b[field]!) return -1
      if (a[field]! > b[field]!) return 1
      return 0
    })
  }
  watch(() => sortField.field, (field, oldField) => {
    if (field) sort(field)
    else if (oldField !== 'date') sort('date')
  })

  return {
    students_prg,
    students_adm,
    ...useStatusBuffer(students_adm, () => {if (sortField.field) sort(sortField.field)}),
    sortField,
  }
}
