import {ref, toRefs, watch} from 'vue'
import {IAuthFormFields} from '@/use/form'

export function useValidation(fields: IAuthFormFields) {
  const [pass2, tel] = [ref<HTMLInputElement>(), ref<HTMLInputElement>()]

  function equivalenceValidation() {
    if (pass2.value) {
      const valid = fields.password === fields.secondPassword
      pass2.value.setCustomValidity(valid ? '' : 'Пароли не совпадают.')
    }
  }

  function telLengthValidation() {
    if (tel.value) {
      const valid = fields.tel.length === 15
      tel.value.setCustomValidity(valid ? '' : 'Номер введён не полностью.')
    }
  }

  watch(toRefs(fields).password, equivalenceValidation)
  watch(toRefs(fields).secondPassword, equivalenceValidation)
  watch(toRefs(fields).tel, telLengthValidation)

  return {
    pass2,
    tel,
  }

}

export const showMessage = (el: HTMLInputElement, message: string) => {
  el.setCustomValidity(message)
  el.reportValidity()
  el.addEventListener('input', () => el.setCustomValidity(''), {once: true})
}
