import progressService from '../service/progress-service'
import {IRequest, Response} from 'express'

class ProgressController {
  async getWorks(req, res: Response, next) {
    try {
      return res.json(await progressService.getWorks())
    } catch (e) {next(e)}
  }

  async getSelfProgress(req: IRequest, res: Response, next) {
    try {
      const {id} = req.user
      return res.json(await progressService.getSelfProgress(id))
    } catch (e) {next(e)}
  }

  async getProgress(req, res: Response, next) {
    try {
      return res.json(await progressService.getProgress())
    } catch (e) {next(e)}
  }

  async changeProgress(req: IRequest<{ userId: number, workId: number, val: boolean }>, res: Response, next) {
    try {
      const {userId, workId, val} = req.body
      await progressService.changeProgress(userId, workId, val)
      return res.json({status: 'OK'})
    } catch (e) {next(e)}
  }

  async getDescription(req: IRequest<{}, {}, { userId: number, workId: number }>, res: Response, next) {
    try {
      const {userId, workId} = req.query
      return res.json(await progressService.getDescription(userId, workId))
    } catch (e) {next(e)}
  }

  async setDescription(req: IRequest<{ userId: number, workId: number, val: string }>, res: Response, next) {
    try {
      const {userId, workId, val} = req.body
      await progressService.setDescription(userId, workId, val)
      return res.json({status: 'OK'})
    } catch (e) {next(e)}
  }
}

export = new ProgressController();
