import {IRequest, Response} from 'express'

import reportService, {IReport, ITask} from '../service/report-service'

class ReportController {
  async getReportTasks(req, res: Response, next) {
    try {
      return res.json(await reportService.getReports())
    } catch (e) {next(e)}
  }

  async getReportProgress(req, res: Response, next) {
    try {
      return res.json(await reportService.getReportProgress())
    } catch (e) {next(e)}
  }

  // async changeReportProgress(req, res, next) {
  //     try {
  //         const {userId, reportId, value} = req.body
  //         return res.json(await reportService.changeReportProgress(userId, reportId, value))
  //     } catch (e) {next(e)}
  // }

  async getReportTasksSelf(req: IRequest, res: Response, next) {
    try {
      const {id} = req.user
      return res.json(await reportService.getReportsSelf(id))
    } catch (e) {next(e)}
  }

  async uploadReport(req: IRequest<{ reportId: number, link: string }>, res: Response, next) {
    try {
      const {reportId, link} = req.body
      const {id} = req.user
      return res.json(await reportService.uploadReport(id, reportId, link))
    } catch (e) {next(e)}
  }

  async setReport(req: IRequest<Omit<ITask, 'members' | 'id'> & Pick<IReport, 'reportId'>>, res: Response, next) {
    try {
      const {reportId, title, task, deadline, limit} = req.body
      return res.json(await reportService.setReport(reportId, title, task, deadline, limit))
    } catch (e) {next(e)}
  }

  async createReport(req: IRequest<Pick<ITask, 'task' | 'title'> & Pick<IReport, 'reportId'>>, res: Response, next) {
    try {
      const {reportId, title, task} = req.body
      await reportService.setReport(reportId, title, task)
      return res.json({status: 'OK'})
    } catch (e) {next(e)}
  }

  async getProject(req: IRequest<{}, {}, Pick<IReport, 'reportId'>>, res: Response, next) {
    try {
      const {reportId} = req.query
      return res.json(await reportService.getProject(reportId))
    } catch (e) {next(e)}
  }

  async enrolment(req: IRequest<Pick<IReport, 'reportId'> & { value: boolean }>, res: Response, next) {
    try {
      const {reportId, value} = req.body
      const {id} = req.user
      return res.json(await reportService.enrolment(id, reportId, value))
    } catch (e) {next(e)}
  }

  async delete(req: IRequest<{ projectId: number }>, res: Response, next) {
    try {
      const {projectId} = req.body
      await reportService.delete(projectId)
      return res.json({status: 'OK'})
    } catch (e) {next(e)}
  }

  // async getReport(req, res, next) {
  //     try {
  //         const {userId, reportId} = req.query
  //         return res.json(await reportService.getReport(userId, reportId))
  //     } catch (e) {next(e)}
  // }
}

export = new ReportController()
