import {Express, NextFunction, Request, Response, Router} from 'express'
import {IUserDto} from '../dtos/user-dto'
import {Server} from 'http'
import {UploadedFile} from 'express-fileupload'

declare module 'express' {
  interface IRequest<T = {}, P = {}, Q = {}> extends Omit<Request, 'params' | 'query'> {
    user: IUserDto,
    body: T,
    files?: { [key: number]: UploadedFile },
    cookies: {
      refreshToken: string
    },
    params: P,
    query: Q
  }

  type IExpress = Express & {
    listen: (port: number, hostname?: string) => Server
  }

  type IExpressRouter = Router & {
    [key in 'get' | 'post' | 'put' | 'delete']: (route: string, ...middlewares: ((req: IRequest<any, any, any>, res: Response, next: NextFunction) => any)[]) => void
  }
}
