// noinspection JSIgnoredPromiseFromCall

import dotenv from 'dotenv'

dotenv.config()

const HOST = process.env.NODE_ENV === 'development' ? '192.168.0.14' : undefined
const PORT = Number(process.env.PORT || 3000)

import morgan from 'morgan'
import cookieParser from 'cookie-parser'
import fileUpload from 'express-fileupload'
import cors from 'cors'

import fs from 'fs'
import path from 'path'
import express, {IExpress} from 'express'
import mysql from 'mysql2/promise'

import {router} from './router'
import ErrorMiddleware from './middlewares/error-middleware'

const app = express() as IExpress
app.set('port', PORT)


app.use(morgan(':date[web]'))
app.use(morgan('dev'))
app.use(morgan('combined', {stream: fs.createWriteStream('./server.log', {flags: 'a'})}))


app.use(express.json())
app.use(express.urlencoded({extended: false}))
app.use(cookieParser())
app.use(fileUpload({}))
app.use(cors({
  credentials: true,
  origin: [process.env.CLIENT_URL!, process.env.WHITE_URL!],
  optionsSuccessStatus: 200,
}))


app.use('/api', router)
app.use('/api/avatars', express.static(path.join(__dirname, '..', 'avatars')))
app.use('/api/avatars/admin', express.static(path.join(__dirname, '..', 'avatars')))
app.use(ErrorMiddleware)


async function getEnvFromDb(...names: string[]) {
  for (const name of names) {
    const [[value]] = await mysql.db.query<{ val: number }>('SELECT `val` FROM `variables` WHERE `var` = ?', [name])
    process.env[name] = String(value?.val)
  }
}

async function start() {
  try {
    mysql.db = await mysql.createPool({
      connectionLimit: 3,
      host: process.env.MYSQL_HOST,
      user: process.env.MYSQL_USER,
      password: process.env.MYSQL_PWD,
      database: process.env.MYSQL_DB,
    })
    console.log('[OK] Connection to database is successful')

    await getEnvFromDb('isAllowRegistration')
    console.log('[OK] Local variables was successfully registered')

    app.listen(PORT, HOST)
    console.log(`[OK] Server is running on ${HOST ?? 'localhost'}:${PORT}`)
  } catch (e) {
    console.log('[ERR] Failed to connect to database:\n', e)
  }
}

start()
