import {UploadedFile} from 'express-fileupload'
import mysql from 'mysql2/promise'
import path from 'path'
import fs from 'fs'
import {nanoid} from 'nanoid'

type IAvatar = {
  fileName: string
} | null

class avatarService {
  async set(id: number, file: UploadedFile) {
    const [[avatar]] = await mysql.db.query<IAvatar>('SELECT `fileName` FROM `avatars` WHERE userId = ?', [id])
    if (avatar) fs.unlinkSync(path.join(__dirname, '..', 'avatars', `${id}_${avatar.fileName}.png`))
    let name: string, dir: string
    do {
      name = nanoid(5)
      dir = path.join(__dirname, '..', 'avatars', `${id}_${name}.png`)
    } while (fs.existsSync(dir))
    await file.mv(dir)
    await mysql.db.query('REPLACE INTO `avatars` (`userId`, `fileName`) VALUES (?, ?);', [id, name])
    return {name}
  }

  async get(id: number) {
    const [[avatar]] = await mysql.db.query<IAvatar>('SELECT `fileName` FROM `avatars` WHERE userId = ?', [id])
    return avatar?.fileName
  }
}

export = new avatarService()
