import nodemailer, {Transporter} from 'nodemailer'
import SMTPTransport from 'nodemailer/lib/smtp-transport'

class mailService {
  transporter: Transporter

  constructor() {
    this.transporter = nodemailer.createTransport({
      host: process.env.SMTP_HOST,
      port: process.env.SMTP_PORT,
      secureConnection: false,
      auth: {
        user: process.env.SMTP_USER,
        pass: process.env.SMTP_PASSWORD,
      },
      tls: {ciphers: 'SSLv3'},
    } as SMTPTransport.Options)
  }

  async sendMail(to: string, type: 'activation' | 'rejection' | 'acceptance', link?: string) {
    const configs = {
      activation: {
        subject: 'Активация аккаунта на ' + process.env.CLIENT_URL,
        html: this.makeActivationMail(link),
      },
      rejection: {
        subject: process.env.CLIENT_URL,
        html: this.makeRejectionMail(),
      },
      acceptance: {
        subject: process.env.CLIENT_URL,
        html: this.makeAcceptanceMail(),
      },
    }

    await this.transporter.sendMail({
      from: process.env.SMTP_USER,
      to,
      text: '',
      ...configs[type],
    })
  }

  makeActivationMail(link) {
    // noinspection HtmlDeprecatedAttribute
    return `
                <table width="100%" border="0" cellspacing="0" cellpadding="0">
                    <tr>
                        <td align="center">
                            <div style="background:white;color:black;padding:0 1em;font-family:'Montserrat',sans-serif;font-size:1.3em;text-align:center; max-width: 600px; border: 3px solid black; border-radius: 10px">
                                <h3>Для активации аккаунта студента курса <br> 
                                <a href="${process.env.CLIENT_URL}" target="_blank" style="color:#ac3bef;text-decoration:none;cursor:pointer;" >Kotlin Fullstack Developer</a> пройдите по ссылке:</h3>
                                <a  target="_blank" href="${link}" style="color:black;cursor:pointer;text-decoration: underline;" >${link}</a>
                                <p>Ссылка для активации будет активна в течение 15 минут.</p>
                            </div>
                        </td>
                    </tr>
                </table>
        `
  }

  makeRejectionMail() {
    // noinspection HtmlDeprecatedAttribute
    return `
                <table width="100%" border="0" cellspacing="0" cellpadding="0">
                    <tr>
                        <td align="center">
                            <div style="background:white;color:black;padding:0 1em;font-family:'Montserrat',sans-serif;font-size:1.3em;text-align:center; max-width: 600px; border: 3px solid black; border-radius: 10px">
                                <h3>К сожалению, вы не прошли на курс <br>
                                <a href="${process.env.CLIENT_URL}" target="_blank" style="color:#ac3bef;text-decoration:none;cursor:pointer;" >Kotlin Fullstack Developer</a> :( <br>
                                Надеемся увидеть вашу заявку в следующий раз!</h3>
                            </div>
                        </td>
                    </tr>
                </table>
        `
  }

  makeAcceptanceMail() {
    // noinspection HtmlDeprecatedAttribute
    return `
                <table width="100%" border="0" cellspacing="0" cellpadding="0">
                    <tr>
                        <td align="center">
                            <div style="background:white;color:black;padding:0 1em;font-family:'Montserrat',sans-serif;font-size:1.3em;text-align:center; max-width: 600px; border: 3px solid black; border-radius: 10px">
                                <h3>Вы зачислены на курс <br>
                                <a href="${process.env.CLIENT_URL}" target="_blank" style="color:#ac3bef;text-decoration:none;cursor:pointer;" >Kotlin Fullstack Developer</a>! <br>
                                Вскоре вы получите всю необходимую информацию!</h3>
                            </div>
                        </td>
                    </tr>
                </table>
        `
  }
}

export = new mailService()
