import mysql from 'mysql2/promise'

class ProgressService {
  async getWorks() {
    const [unparsedWorks] = await mysql.db.query<{ id: number, name: string }, '!'>('SELECT * FROM `works`')
    const works: string[] = []
    for (const {id, name} of unparsedWorks) works[id] = name
    return works
  }

  async getSelfProgress(id: number) {
    type IProgress = {
      workId: number,
      credited: boolean,
      description: string
    }
    const [unparsedProgress] = await mysql.db.query<IProgress, '!'>('SELECT `workId`, `credited`, `description` FROM `progress` WHERE `userId` = ?', [id])
    const progress: { [key: number]: Omit<IProgress, 'workId'> } = {}
    for (const {workId, credited, description} of unparsedProgress) progress[workId] = {credited, description}
    return progress
  }

  async getProgress() {
    const [unparsedProgress] = await mysql.db.query<{
      userId: number,
      workId: number,
      credited: boolean,
    }, '!'>('SELECT `u`.`id` AS `userId`, `p`.`workId`, `p`.`credited` FROM `kfc`.`progress` `p` RIGHT OUTER JOIN `kfc`.`users` `u` ON `u`.`id` = `p`.`userId` WHERE `u`.`status` >= 200 AND `u`.`status` < 300;')
    const [[{worksCount}]] = await mysql.db.query<{ worksCount: number }, '!'>('SELECT COUNT(*) AS `worksCount` FROM `works`')
    const users: { [key: string]: boolean[] } = {}
    for (const {userId, workId, credited} of unparsedProgress) {
      if (!users[userId]) users[userId] = Array(worksCount).fill(false)
      users[userId][workId] = !!credited
    }
    return users
  }

  async changeProgress(userId: number, workId: number, val: boolean) {
    await mysql.db.query('INSERT INTO `progress` (`userId`, `workId`, `credited`) VALUES (?, ?, ?) ON DUPLICATE KEY UPDATE `credited` = ?;', [userId, workId, val, val])
  }

  async getDescription(userId: number, workId: number) {
    const [descriptions] = await mysql.db.query<{ description: string }>('SELECT `description` FROM `progress` WHERE `userId` = ? AND `workId` = ?', [userId, workId])
    return descriptions?.[0]?.description
  }

  async setDescription(userId: number, workId: number, val: string) {
    await mysql.db.query('INSERT INTO `progress` (`userId`, `workId`, `description`) VALUES (?, ?, ?) ON DUPLICATE KEY UPDATE `description` = ?;', [userId, workId, val, val])
  }
}

export = new ProgressService()
