import mysql from 'mysql2/promise'
import jwt, {JwtPayload} from 'jsonwebtoken'

class tokenService {
  generateTokens(payload: any) {
    const accessToken = jwt.sign(payload, process.env.JWT_ACCESS_SECRET!, {expiresIn: `${process.env.JWT_ACCESS_LIVETIME}m`})
    const refreshToken = jwt.sign(payload, process.env.JWT_REFRESH_SECRET!, {expiresIn: `${process.env.JWT_REFRESH_LIVETIME}d`})
    return {
      accessToken,
      refreshToken,
    }
  }

  async saveToken(userId: number, refreshToken: string) {
    return await mysql.db.query('REPLACE INTO `tokens` (`userId`, `refreshToken`) VALUES (?, ?);', [userId, refreshToken])
  }

  async removeToken(refreshToken: string) {
    return mysql.db.query('DELETE FROM `tokens` WHERE `refreshToken` = ?', [refreshToken])
  }

  validateAccessToken<T extends JwtPayload>(token: string) {
    try {
      return jwt.verify(token, process.env.JWT_ACCESS_SECRET!) as T
    } catch (e) {return null}
  }

  validateRefreshToken<T extends JwtPayload>(token: string) {
    try {
      return jwt.verify(token, process.env.JWT_REFRESH_SECRET!) as T
    } catch (e) {return null}
  }

  async findToken(refreshToken: string) {
    const [[token]] = await mysql.db.query<{ refreshToken: string }>('SELECT `refreshToken` FROM `tokens` WHERE `refreshToken` = ?', [refreshToken])
    return token
  }
}

export = new tokenService()
